pub struct CliArgs {
pub command: CliCommand,
pub verbose: Verbosity<InfoLevel>,
}Expand description
CLI arguments.
Fields
command: CliCommandThe command to be run.
verbose: Verbosity<InfoLevel>Verbosity.
Implementations
Sourceimpl CliArgs
impl CliArgs
Sourcepub fn new_from_args<I, T>(args: I) -> Self
pub fn new_from_args<I, T>(args: I) -> Self
Parse CLI arguments from an iterator.
Sourcepub fn run_cli(self)
pub fn run_cli(self)
Entrypoint for cli - process arguments and run commands.
Process exits on error.
Sourcepub fn run_with_io(self, input: impl Read) -> Result<Vec<u8>, RunWithIoError>
pub fn run_with_io(self, input: impl Read) -> Result<Vec<u8>, RunWithIoError>
Run a CLI command with bytes input and capture bytes output.
This provides a programmatic interface to the CLI.
Unlike run_cli(), this method:
- Accepts input instead of reading from stdin/files
- Returns output as a byte vector instead of writing to stdout/files
Arguments
input- The input data as bytes (e.g., a HUGR package)
Returns
Returns Ok(Vec<u8>) with the command output, or an error on failure.
Note
The gen-extensions and external commands don’t support byte I/O
and should use the normal run_cli() method instead.